==> kazehakase-0.3.4.tar.gz: kazehakase-0.3.4/src/mozilla/MozillaPrivate.h <==
/*
 *  Copyright (C) 2004 Marco Pesenti Gritti
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  $Id: MozillaPrivate.h,v 1.9 2005/10/24 12:27:05 ikezoe Exp $
 */

/*
 * Based on MozillaPrivate.cpp in Epiphany-1.5.1.
 *  Copyright (C) 2003, 2004 Marco Pesenti Gritti
 */

#ifndef __MOZILLA_PRIVATE_H__
#define __MOZILLA_PRIVATE_H__

#include <glib.h>
#include <gtk/gtk.h>
#define MOZILLA_INTERNAL_API
#include <nsIPrintSettings.h>
#include <nsIDOMWindow.h>
#include <nsIDOMDocument.h>
#include <nsIDOMRange.h>
#include <nsISelection.h>
#include <nsIDocShell.h>
#include <nsIBaseWindow.h>
#include <nsIDOMEventReceiver.h>
#undef MOZILLA_INTERNAL_API

namespace MozillaPrivate
{
	GList    *GetPrinterList      ();
	gboolean  CreatePrintSettings (nsIPrintSettings **options);
	gboolean  GetRootRange        (nsIDOMDocument *domDoc, nsIDOMRange *range);
	gboolean  GetSelectedRange    (nsIDOMDocument *domDoc, nsIDOMRange *range,
				       nsISelection *selection, gboolean backward);
	gboolean  SetZoomOnDocShell   (float aZoom, nsIDocShell *DocShell);
	GdkWindow *GetGdkWindow       (nsIBaseWindow *window);
	gboolean  GetEventReceiver    (nsIDOMWindow *domWindow, nsIDOMEventReceiver **receiver);
	gchar    *GetURIForDOMWindow  (nsIDOMWindow *aDOMWindow);
	const char *Unescape          (const char *text);	
}
#endif /* __MOZILLA_PRIVATE_H__ */

==> kazehakase_0.4.3.orig.tar.gz: kazehakase-0.4.3.orig/src/mozilla/MozillaPrivate.h <==
/*
 *  Copyright (C) 2004 Marco Pesenti Gritti
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  $Id: MozillaPrivate.h,v 1.10 2006/09/11 23:12:23 ikezoe Exp $
 */

/*
 * Based on MozillaPrivate.cpp in Epiphany-1.5.1.
 *  Copyright (C) 2003, 2004 Marco Pesenti Gritti
 */

#ifndef __MOZILLA_PRIVATE_H__
#define __MOZILLA_PRIVATE_H__

#include <glib.h>
#include <gtk/gtk.h>
#define MOZILLA_INTERNAL_API
#include <nsIPrintSettings.h>
#include <nsIDOMWindow.h>
#include <nsIDOMDocument.h>
#include <nsIDOMRange.h>
#include <nsISelection.h>
#include <nsIDocShell.h>
#include <nsIBaseWindow.h>
#include <nsIDOMEventReceiver.h>
#undef MOZILLA_INTERNAL_API

namespace MozillaPrivate
{
	GList    *GetPrinterList      ();
	gboolean  CreatePrintSettings (nsIPrintSettings **options);
	gboolean  GetRootRange        (nsIDOMDocument *domDoc, nsIDOMRange *range);
	gboolean  GetSelectedRange    (nsIDOMDocument *domDoc, nsIDOMRange *range,
				       nsISelection *selection, gboolean backward);
	gboolean  SetZoomOnDocShell   (float aZoom, nsIDocShell *DocShell);
	GdkWindow *GetGdkWindow       (nsIBaseWindow *window);
	gboolean  GetEventReceiver    (nsIDOMWindow *domWindow, nsIDOMEventReceiver **receiver);
	gchar    *GetURIForDOMWindow  (nsIDOMWindow *aDOMWindow);
	const char *Unescape          (const char *text);	
#ifdef MOZ_NSICANVASRENDERINGCONTEXTINTERNAL_HAVE_GETINPUTSTREAM_
	gboolean  CreateThumbnail     (nsIDOMWindow *domWindow, const gchar *uri);
#endif
}
#endif /* __MOZILLA_PRIVATE_H__ */
